# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"get_links": "linkcheck.ipynb",
         "local_urls": "linkcheck.ipynb",
         "broken_local": "linkcheck.ipynb",
         "broken_urls": "linkcheck.ipynb",
         "link_check": "linkcheck.ipynb"}

modules = ["linkcheck.py"]

doc_url = "https://fastlinkcheck.fast.ai/"

git_url = "https://github.com/fastai/fastlinkcheck/tree/master/"

def custom_doc_links(name): return None
